## What's Changed

### Features

- feat: supports to display plugin CHANGELOG.md ([#4337](https://github.com/AstrBotDevs/AstrBot/issues/4337))

### Fixes

- fix: conversation was still saved to the context after `stop_event` ([#4345](https://github.com/AstrBotDevs/AstrBot/issues/4345))
- fix: on_waiting_llm_request hook did not check message validity ([#4349](https://github.com/AstrBotDevs/AstrBot/issues/4349))
fix(webui): maintain international consistency of the 'repo' button ([#4358](https://github.com/AstrBotDevs/AstrBot/issues/4358))

### Improvements

- plugin marketplace search supports matching display names. ([#4332](https://github.com/AstrBotDevs/AstrBot/issues/4332))
